@@ -1,4 +1,4 @@
-from unittest.mock import MagicMock
+from mock import MagicMock
 from pystandalonehtml import cli
 
 def test_cli():
@@ -13,4 +13,4 @@ def test_cli():
     cli.main()
 
     # Verify
-    htmlcoverter_mock.assert_called_with('value1', 'value2')
\ No newline at end of file
+    htmlcoverter_mock.assert_called_with('value1', 'value2')
